AirgapKey class

One key found in a signer export.

Constructors

AirgapKey.fromJson(Map<String, dynamic> j)

Properties

address → String
The address this key maps to (first receive address for an xpub).
final
chain → String
bitcoin | ethereum | solana | unsupported.
final
chainCode → String?
final
coinType → int?
final
curve → String
final
hashCode → int
The hash code for this object.
no setterinherited
masterFingerprint → String?
final
name → String?
final
note → String?
final
path → String
Full path from the signer's master, e.g. m/84'/0'/0'.
final
pubkey → String
final
reason → String?
Why the key is unsupported, when it is.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → String
Bitcoin script kind (p2wpkh, p2sh:p2wpkh, p2pkh, p2tr).
final
usable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited