BitcoinUTXOList class

The Account:listUTXOs response shape.

Constructors

BitcoinUTXOList({required String chainId, required List<BitcoinUTXO> utxos})
const
BitcoinUTXOList.fromJson(Map<String, dynamic> json)
factory

Properties

chainId String
Echoes the resolved network's chain id (e.g. "litecoin", "bitcoin").
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utxos List<BitcoinUTXO>
Available UTXOs sorted largest-amount-first.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited