ContactApi class

Contact CRUD.

Constructors

ContactApi(Transport _conn)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required String name, required String address, required String type, String memo = ''}) Future<Contact>
Create a new contact.
delete(String id) Future<void>
Delete a contact.
get(String id) Future<Contact>
Get a contact by ID.
list() Future<List<Contact>>
List all contacts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(String id, {String? name, String? address, String? type, String? memo}) Future<Contact>
Update a contact. Only non-null fields are sent.

Operators

operator ==(Object other) bool
The equality operator.
inherited