NameApi class

ENS (.eth) and SNS (.sol) name resolution.

Constructors

NameApi(Transport _conn)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String name) Future<NameResolution>
Resolve an ENS or SNS name to an on-chain address.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited