NextAddress class

The next available HD address.

Constructors

NextAddress({required String address, required String path, required int index, required String chain})
const
NextAddress.fromJson(Map<String, dynamic> json)
factory

Properties

address String
Derived address.
final
chain String
Chain: receive or change.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Child index within the chain.
final
path String
Derivation path under the account xpub (e.g. m/0/5).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited