OnboardingState class
Onboarding state returned by Info:onboarding.
Constructors
-
OnboardingState({required bool hasWallet, required bool hasAccount, required Map<
String, dynamic> raw}) -
const
-
OnboardingState.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hasAccount → bool
-
Whether the user has created at least one account.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWallet → bool
-
Whether the user has created at least one wallet.
final
-
raw
→ Map<
String, dynamic> -
Raw JSON response for accessing additional fields.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited