SignedMessage class

Result of AccountApi.signMessage.

Constructors

SignedMessage({required String signature, String? publicKey})
const
SignedMessage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
publicKey String?
Base58-encoded public key of the signer (Solana mode only; null for EVM).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
Encoded signature. Format depends on the signing mode:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited