WarningSeverity class

Severity bucket for a Warning.

Constructors

WarningSeverity()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

block → const String
The transaction is guaranteed to fail; the app should refuse to sign it.
info → const String
Purely informational — show for context, don't require confirmation.
warn → const String
Something surprising the user should confirm before signing.