NameResolution class
Result of resolving an ENS or SNS name to a blockchain address.
Constructors
- NameResolution({required String name, required String address, required String network})
-
const
-
NameResolution.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address → String
-
The resolved on-chain address.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The original name that was resolved (e.g.
vitalik.eth).final - network → String
-
The network family:
ethereum(ENS) orsolana(SNS).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited